@@ -7,9 +7,11 @@ from obitools.utils.bioseq import uniqSequence,sortSequence
 from obitools.align import lenlcs
 
 from obitools.options.taxonomyfilter import addTaxonomyDBOptions,loadTaxonomyDatabase
-
-
+from obitools.ecobarcode.databases import referenceDBIterator
 from obitools.options import getOptionManager
+from obitools.ecobarcode.rawdata import sequenceIterator
+import sys
+from obitools.ecobarcode.ecotag import storeIdentification
 
 
 def addSearchOptions(optionManager):
@@ -64,6 +66,16 @@ def addSearchOptions(optionManager):
                              default=False,
                              help='Write results in a tabular format')
     
+    optionManager.add_option('--store-in-db',
+                             action='store_true',dest='storeindb',
+                             default=False,
+                             help='Write results in an ecobarcode DB')
+    
+    optionManager.add_option('--update-db',
+                             action='store_true',dest='updatedb',
+                             default=False,
+                             help='Run identification only on new sequences')
+    
     optionManager.add_option('--sort',
                              action='store',dest='sort',
                              type='string',
@@ -135,7 +147,16 @@ if __name__=='__main__':
 
     taxonomy = loadTaxonomyDatabase(options)
     
-    db = list(fastaNucIterator(options.database))
+    if (hasattr(options, 'ecobarcodedb')):
+        print >>sys.stderr,"Reading reference DB ...",
+        db = list(referenceDBIterator(options))  
+            
+
+        print >>sys.stderr," : %d" % len(db)
+        if options.primer is not None:
+            entries = sequenceIterator(options)  
+    else:
+        db = list(fastaNucIterator(options.database))
 #    print "##########@",options.large
     taxonlink = {}
 
@@ -208,6 +229,10 @@ if __name__=='__main__':
             
         if options.table:
             print '\t'.join([str(x) for x in data])
+        elif options.storeindb:
+            storeIdentification(seq.id,data[0]=='ID',data[8],
+                                dict((s[0]['refdbid'],s[1]) for s in match),
+                                options)
         else:
             seq['id_status']=data[0]=='ID'
             seq['count']=data[6]
@@ -283,4 +308,9 @@ if __name__=='__main__':
                 if options.sequence:
                     d.append('--')
                 print '\t'.join([str(x) for x in d])
+                
+    if (hasattr(options, 'ecobarcodedb')):
+        options.ecobarcodedb.commit()
+        options.ecobarcodedb.close()
+        
                 
\ No newline at end of file
