@@ -13,7 +13,7 @@ import math
 from obitools.options import getOptionManager
 from obitools.utils import ColumnFile
 from obitools.align import FreeEndGap
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 
 
 
@@ -419,12 +419,18 @@ if __name__ == '__main__':
     if options.unidentified is not None:
         unidentified = open(options.unidentified,"w")
     
+    writer = sequenceWriterGenerator(options)
+    if options.unidentified is not None:
+        unidentified = sequenceWriterGenerator(options,open(options.unidentified,"w"))
+    else :
+        unidentified = None
+        
     for seq in entries:
         good,seq = annotate(seq,options)
         if good:
-            printOutput(options,seq)
-        elif options.unidentified is not None:
-            printOutput(options,seq,unidentified)
+            writer(seq)
+        elif unidentified is not None:
+            unidentified(seq)
             
     
     
\ No newline at end of file
