@@ -6,10 +6,8 @@ from obitools.options.bioseqfilter import addSequenceFilteringOptions
 from obitools.options.bioseqfilter import filterGenerator
 from obitools.options.bioseqedittag import addSequenceEditTagOptions
 from obitools.options.bioseqedittag import sequenceTaggerGenerator
-from obitools.format.options import addInOutputOption, printOutput
-
-
-    
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
+        
     
 if __name__=='__main__':
     
@@ -19,18 +17,13 @@ if __name__=='__main__':
 
     (options, entries) = optionParser()
     
-    if not options.noPsyco:
-        try:
-            import psyco
-            psyco.full()
-        except ImportError:
-            pass
-
+    writer = sequenceWriterGenerator(options)
+    
     sequenceTagger = sequenceTaggerGenerator(options)
     goodFasta = filterGenerator(options)
     
     for seq in entries:
         if goodFasta(seq):
             sequenceTagger(seq)
-        printOutput(options,seq)
+        writer(seq)
             
