@@ -4,7 +4,7 @@
 from obitools.options import getOptionManager
 from obitools.options.bioseqfilter import addSequenceFilteringOptions
 from obitools.options.bioseqfilter import filterGenerator
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 
 
 if __name__=='__main__':
@@ -14,11 +14,12 @@ if __name__=='__main__':
     (options, entries) = optionParser()
     
     goodFasta = filterGenerator(options)
+    writer = sequenceWriterGenerator(options)
     
     for seq in entries:
         if goodFasta(seq):
-            printOutput(options,seq.complement())
+            writer(seq.complement())
         else:
-            printOutput(options,seq)
+            writer(seq)
 
             
\ No newline at end of file
