@@ -5,7 +5,7 @@ Created on 15 dec. 2009
 @author: coissac
 '''
 import sys
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 from obitools.options import getOptionManager
 
 
@@ -23,10 +23,12 @@ if __name__ == '__main__':
     
     (options, entries) = optionParser()
     i=0
+
+    writer = sequenceWriterGenerator(options)
     
     for s in entries:
         if i < options.count:
-            printOutput(options,s)
+            writer(s)
             i+=1
         else:
             sys.exit(0)
