@@ -7,7 +7,7 @@ Created on 1 nov. 2009
 
 from obitools.options import getOptionManager
 from obitools.sample import weigthedSample
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 
 def addSampleOptions(optionManager):
     optionManager.add_option('-s','--sample-size',
@@ -44,11 +44,13 @@ if __name__ == '__main__':
         idx+=1
         
     sample =weigthedSample(distribution, options.size)
+
+    writer = sequenceWriterGenerator(options)
     
     for idx in sample:
         seq = db[idx]
         seq['count']=sample[idx]
-        printOutput(options,seq)
+        writer(seq)
         
         
 
