@@ -4,7 +4,7 @@ Created on 6 juil. 2010
 
 @author: coissac
 '''
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 from obitools.options import getOptionManager
 from obitools.format.sequence import autoSequenceIterator
 
@@ -18,6 +18,11 @@ def addSelectOptions(optionManager):
                              help="file containing sample sequences to select on "
                                   "on the base of their identifier")
 
+    optionManager.add_option('-v',
+                             action="store_true", dest="invert",
+                             default=False,
+                             help="invert selection")
+
 
 
 
@@ -26,9 +31,16 @@ if __name__ == '__main__':
     
     (options, entries) = optionParser()
     
-    idset=set(x.id for x in  autoSequenceIterator(options.identifier))
+    idset=set(x.strip() for x in  open(options.identifier))
+    writer = sequenceWriterGenerator(options)
+    
+    def invert(x):
+        if options.invert:
+            return not x
+        else:
+            return x
     
     for seq in entries:
-        if seq.id in idset:
-            printOutput(options,seq)
+        if invert(seq.id in idset):
+            writer(seq)
         
