@@ -4,7 +4,7 @@ Created on 15 dec. 2009
 
 @author: coissac
 '''
-from obitools.format.options import addInOutputOption, printOutput
+from obitools.format.options import addInOutputOption, sequenceWriterGenerator
 from obitools.options import getOptionManager
 import collections
 
@@ -24,9 +24,11 @@ if __name__ == '__main__':
     i=0
     
     queue = collections.deque(entries,options.count)
-    
+
+    writer = sequenceWriterGenerator(options)
+   
     while queue:
-        printOutput(options,queue.popleft())
+        writer(queue.popleft())
         
         
         
