@@ -270,17 +270,17 @@ class TaxonomyDump(Taxonomy):
         print >>sys.stderr,"Adding scientific name..."
     
         self._name=[]
-        for taxid,name,classname in TaxonomyDump._nameIterator('%s/names.dmp' % taxdir):
+        for taxid,name,classname in self._nameIterator('%s/names.dmp' % taxdir):
             self._name.append((name,classname,self._index[taxid]))
             if classname == 'scientific name':
                 self._taxonomy[self._index[taxid]].append(name)
             
         print >>sys.stderr,"Adding taxid alias..."
-        for taxid,current in TaxonomyDump._mergedNodeIterator('%s/merged.dmp' % taxdir):
+        for taxid,current in self._mergedNodeIterator('%s/merged.dmp' % taxdir):
             self._index[taxid]=self._index[current]
         
         print >>sys.stderr,"Adding deleted taxid..."
-        for taxid in TaxonomyDump._deletedNodeIterator('%s/delnodes.dmp' % taxdir):
+        for taxid in self._deletedNodeIterator('%s/delnodes.dmp' % taxdir):
             self._index[taxid]=None
             
     def _taxonCmp(t1,t2):
@@ -350,7 +350,7 @@ class TaxonomyDump(Taxonomy):
         self._ranks=ranks
         self._index=index 
 
-    def _nameIterator(file):
+    def _nameIterator(self,file):
         file = universalOpen(file)
         names = ColumnFile(file, 
                            sep='|', 
@@ -358,20 +358,16 @@ class TaxonomyDump(Taxonomy):
                                   str,str))
         for taxid,name,unique,classname,white in names:
             yield taxid,name,classname
-            
-    _nameIterator=staticmethod(_nameIterator)
-            
-    def _mergedNodeIterator(file):
+                        
+    def _mergedNodeIterator(self,file):
         file = universalOpen(file)
         merged = ColumnFile(file, 
                            sep='|', 
                            types=(int,int,str))
         for taxid,current,white in merged:
                 yield taxid,current
-
-    _mergedNodeIterator=staticmethod(_mergedNodeIterator)
       
-    def _deletedNodeIterator(file):
+    def _deletedNodeIterator(self,file):
         file = universalOpen(file)
         deleted = ColumnFile(file, 
                            sep='|', 
@@ -379,8 +375,6 @@ class TaxonomyDump(Taxonomy):
         for taxid,white in deleted:
                 yield taxid
         
-    _deletedNodeIterator=staticmethod(_deletedNodeIterator)
-
 #####
 #
 #
@@ -426,9 +420,10 @@ def ecoTaxonomyWriter(prefix, taxonomy):
                                  taxid,
                                  index)
         except struct.error,e:
+            print >>sys.stderr,(totalSize,taxid,index)
             print >>sys.stderr,"Total size : %d  taxid : %d  index : %d" %(totalSize,taxid,index)
             raise e
-        
+         
         return packed
                     
     def ecoNamePacker(name):
