@@ -14,14 +14,25 @@ from obitools.fnaqual.quality import qualityIterator
 from obitools.fasta import formatFasta, rawFastaIterator
 from obitools.fastq import formatFastq
 
-from obitools.format._format import printOutput
+from obitools.ecopcr.sequence import EcoPCRDBSequenceWriter
+from obitools.ecopcr.options  import loadTaxonomyDatabase
+
+#from obitools.format._format import printOutput
 
 from array import array
 from itertools import chain
+import sys
 
+import re
+from obitools.ecopcr import EcoPCRFile
 
 
 def addInputFormatOption(optionManager):
+    optionManager.add_option('--rank',
+                             action="store_true", dest='addrank',
+                             default=False,
+                             help="add a rank attribute to the sequence "
+                                  "indicating the sequence position in the input data")
     optionManager.add_option('--genbank',
                              action="store_const", dest="seqinformat",
                              default=None,
@@ -39,6 +50,12 @@ def addInputFormatOption(optionManager):
                              const='fasta',
                              help="input file is in fasta nucleic format (including obitools fasta extentions)")
 
+    optionManager.add_option('--ecopcr',
+                             action="store_const", dest="seqinformat",
+                             default=None,
+                             const='ecopcr',
+                             help="input file is in fasta nucleic format (including obitools fasta extentions)")
+
     optionManager.add_option('--raw-fasta',
                              action="store_const", dest="seqinformat",
                              default=None,
@@ -98,6 +115,10 @@ def addOutputFormatOption(optionManager):
                              default=None,
                              const=formatFasta,
                              help="output sequences in obitools fasta format")
+    optionManager.add_option('--ecopcr-output',
+                             action="store", dest="ecopcroutput",
+                             default=None,
+                             help="output sequences in obitools ecopcr format")
     optionManager.add_option('--uppercase',
                              action='store_true',dest='uppercase',
                              default=False,
@@ -117,6 +138,8 @@ def autoEntriesIterator(options):
     options.outputFormater=formatFasta
     options.outputFormat="fasta"
     
+    ecopcr_pattern = re.compile('^[^ ]+ +| +[0-9]+ +| + [0-9]+ + | +')
+    
     def annotatedIterator(formatIterator):
         options.outputFormater=formatFasta
         options.outputFormat="fasta"
@@ -127,6 +150,15 @@ def autoEntriesIterator(options):
 
         return iterator
 
+    def withRankIterator(formatIterator):
+        def iterator(lineiterator):
+            rank=0
+            for s in formatIterator(lineiterator):
+                rank+=1
+                s['rank']=rank
+                yield s
+
+        return iterator
     def withQualIterator(qualityfile):
         options.outputFormater=formatFastq
         options.outputFormat="fastq"
@@ -163,8 +195,10 @@ def autoEntriesIterator(options):
             reader=emblIterator
         elif first[0:6]=='LOCUS ':
             reader=genbankIterator
+        elif first[0]=="#" or ecopcr_pattern.search(first):
+            reader=EcoPCRFile 
         else:
-            raise AssertionError,'file is not in fasta, fasta, embl, or genbank format'
+            raise AssertionError,'file is not in fasta, fasta, embl, genbank or ecoPCR format'
         
         input = reader(chain([first],lineiterator))
         
@@ -200,15 +234,48 @@ def autoEntriesIterator(options):
             options.outputFormater=formatFastq
             options.outputFormat="fastq"
             reader=fastqIlluminaIterator
+        elif options.seqinformat=='ecopcr':
+            reader=EcoPCRFile
             
         if options.seqinformat=='fna' and options.withqualfile is not None:
             qualfile=qualityIterator(options.withqualfile)
             reader=withQualIterator(qualfile)
             options.outputFormater=formatFastq
             options.outputFormat="fastq"
-        
+            
+    if options.addrank:
+        reader = withRankIterator(reader)
     return reader
 
+def sequenceWriterGenerator(options,output=sys.stdout):
+    class SequenceWriter:
+        def __init__(self,options,file=sys.stdout):
+            self._format=None
+            self._file=file
+            self._upper=options.uppercase
+        def put(self,seq):
+            if self._format is None:
+                self._format=formatFasta
+                if options.output is not None:
+                    self._format=options.output
+                elif options.outputFormater is not None:
+                    self._format=options.outputFormater
+            s = self._format(seq,upper=self._upper)
+            try:
+                self._file.write(s)
+                self._file.write("\n")
+            except IOError:
+                sys.exit(0)
+                
+    if options.ecopcroutput is not None:
+        taxo = loadTaxonomyDatabase(options)
+        writer=EcoPCRDBSequenceWriter(options.ecopcroutput,taxonomy=taxo)
+    else:
+        writer=SequenceWriter(options,output)
         
+    def sequenceWriter(sequence):
+        writer.put(sequence)
+
+    return sequenceWriter
     
     
\ No newline at end of file
